/**
 * Test case for setup.
 * Runs with mocha.
 */
"use strict";

const setup = require('../lib/setup.js'),
    assert = require('assert'),
    coz = require('coz');

describe('setup', ()=> {

    it('Render mocha test', (done) => {
        let bud = setup({
            type: 'mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render nodeunit test', (done) => {
        let bud = setup({
            type: 'nodeunit',
            src: __filename,
            dest: __dirname + '/../tmp/testing-nodeunit/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render jasmine test', (done) => {
        let bud = setup({
            type: 'jasmine',
            src: __filename,
            dest: __dirname + '/../tmp/testing-jasmine/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render route mocha test', (done) => {
        let bud = setup({
            type: 'route-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render component mocha test', (done) => {
        let bud = setup({
            type: 'component-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha-component/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render store mocha test', (done) => {
        let bud = setup({
            type: 'store-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha-store/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render service mocha test', (done) => {
        let bud = setup({
            type: 'service-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha-service/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render mixin mocha test', (done) => {
        let bud = setup({
            type: 'mixin-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha-mixin/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render extension mocha test', (done) => {
        let bud = setup({
            type: 'extension-mocha',
            src: __filename,
            dest: __dirname + '/../tmp/testing-mocha-extension/'
        });
        assert.ok(bud);
        bud.forEach((bud) => {
            assert.ok(bud.tmpl);
            bud.mkdirp = true;
            bud.force = true;
        });
        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });
});


